@@ -51,6 +51,11 @@ get_voteview_rollcall_votes <- function(chamber = "all", congress = NULL,
   full_path <- build_file_path(data_source = "voteview", chamber = chamber, congress = congress,
                                sheet_type = "rollcalls", local = local, local_dir = local_dir)
 
+  # request data from online
+  if (R.utils::isUrl(full_path)) {
+    full_path <- get_online_data(url = full_path, source_name = "Voteview")
+  }
+
   readr::read_csv(full_path, col_types = "ifiDddiidddddccccc") |>
     dplyr::mutate(dplyr::across(.cols = c("session", "clerk_rollnumber"),
                                 .fns = as.integer))
